/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.facade.def.element.impl;

import java.util.Map;

import org.ow2.bonita.facade.def.element.MultiInstantiationDefinition;
import org.ow2.bonita.util.CopyTool;
import org.ow2.novabpm.util.Misc;

public class MultiInstantiationDefinitionImpl implements MultiInstantiationDefinition {

  private String className;
  private String variableId;
  private Map<String, String> parameters;

  public MultiInstantiationDefinitionImpl() { }

  public MultiInstantiationDefinitionImpl(final String variableId, final String className, final Map<String, String> parameters) {
    Misc.badStateIfNull(className, "Cannot build an multiInstantiatorClass with a null class name");
    Misc.badStateIfNull(variableId, "Cannot build an multiInstantiatorClass with a null variable id");
    this.variableId = variableId;
    this.className = className;
    this.parameters = parameters;
  }


  public MultiInstantiationDefinitionImpl(final MultiInstantiationDefinition src) {
    this.variableId = src.getVariableId();
    this.className = src.getClassName();
    this.parameters = CopyTool.copy(src.getParameters());
  }

  public String getClassName() {
    return this.className;
  }

  public Map<String, String> getParameters() {
    return this.parameters;
  }

  public String getVariableId() {
    return this.variableId;
  }
}


