/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.facade.def.majorElement.impl;

import java.util.HashSet;
import java.util.Set;

import org.ow2.bonita.facade.def.element.DeadlineDefinition;
import org.ow2.bonita.facade.def.element.HookDefinition;
import org.ow2.bonita.facade.def.element.MultiInstantiationDefinition;
import org.ow2.bonita.facade.def.element.PerformerAssignDefinition;
import org.ow2.bonita.facade.def.element.SimulationInformationDefinition;
import org.ow2.bonita.facade.def.element.SubFlowDefinition;
import org.ow2.bonita.facade.def.element.ToolDefinition;
import org.ow2.bonita.facade.def.element.TransitionRestrictionDefinition;
import org.ow2.bonita.facade.def.element.impl.DeadlineDefinitionImpl;
import org.ow2.bonita.facade.def.element.impl.HookDefinitionImpl;
import org.ow2.bonita.facade.def.element.impl.MultiInstantiationDefinitionImpl;
import org.ow2.bonita.facade.def.element.impl.PerformerAssignDefinitionImpl;
import org.ow2.bonita.facade.def.element.impl.SimulationInformationDefinitionImpl;
import org.ow2.bonita.facade.def.element.impl.SubFlowDefinitionImpl;
import org.ow2.bonita.facade.def.element.impl.ToolDefinitionImpl;
import org.ow2.bonita.facade.def.element.impl.TransitionRestrictionDefinitionImpl;
import org.ow2.bonita.facade.def.majorElement.ActivityDefinition;
import org.ow2.bonita.facade.def.majorElement.DataFieldDefinition;
import org.ow2.bonita.facade.uuid.ActivityDefinitionUUID;
import org.ow2.bonita.facade.uuid.PackageDefinitionUUID;
import org.ow2.bonita.facade.uuid.ProcessDefinitionUUID;

public class ActivityDefinitionImpl extends ProcessDefinitionRecordImpl implements ActivityDefinition {

  public static class IterationDefinitionImpl implements IterationDef {
    protected String to;
    protected String condition;
    public String getTo() {
      return to;
    }
    public String getCondition() {
      return condition;
    }
    public IterationDefinitionImpl(String to, String condition) {
      this.to = to;
      this.condition = condition;
    }
  }

  protected ActivityDefinitionUUID uuid;
  protected String activityId;
  protected String blockId;
  protected Set<DeadlineDefinition> deadlines;
  protected String description;
  protected String documentation;
  protected FinishMode finishMode;
  protected String icon;
  protected String limit;
  protected String performer;
  protected String priority;
  protected SimulationInformationDefinition simulationInformation;
  protected StartMode startMode;
  protected SubFlowDefinition subFlow;
  protected Set<ToolDefinition> tools;
  protected Set<TransitionRestrictionDefinition> transitionRestrictions;
  protected boolean noImplementation;
  protected boolean route;
  protected Set<HookDefinition> hooks;
  protected PerformerAssignDefinition performerAssign;
  protected Set<DataFieldDefinition> dataFields;

  protected Set<IterationDef> iterations;
  protected MultiInstantiationDefinition activityInstantiator;
  
  protected ActivityDefinitionImpl() { }

  public ActivityDefinitionImpl(ActivityDefinitionUUID activityDefinitionUUID,
      String activityId, PackageDefinitionUUID packageUUID,
      ProcessDefinitionUUID processUUID, String blockId, Set<DeadlineDefinition> deadlines,
      String description, String documentation, FinishMode finishMode,
      String icon, String limit, String name, String performer,
      String priority, SimulationInformationDefinition simulationInformation,
      StartMode startMode, SubFlowDefinition subFlow, Set<ToolDefinition> tools,
      Set<TransitionRestrictionDefinition> transitionRestrictions,
      boolean noImplementation, boolean route, Set<HookDefinition> hooks,
      PerformerAssignDefinition performerAssign, Set<DataFieldDefinition> dataFields,
      Set<IterationDef> iterations, MultiInstantiationDefinition activityInstantiator
  ) {
    super(packageUUID, name, processUUID);
    this.uuid = activityDefinitionUUID;
    this.activityId = activityId;
    this.blockId = blockId;
    this.deadlines = deadlines;
    this.description = description;
    this.documentation = documentation;
    this.finishMode = finishMode;
    this.icon = icon;
    this.limit = limit;
    this.performer = performer;
    this.priority = priority;
    this.simulationInformation = simulationInformation;
    this.startMode = startMode;
    this.subFlow = subFlow;
    this.tools = tools;
    this.transitionRestrictions = transitionRestrictions;
    this.noImplementation = noImplementation;
    this.route = route;
    this.hooks = hooks;
    this.performerAssign = performerAssign;
    this.dataFields = dataFields;
    this.iterations = iterations;
    this.activityInstantiator = activityInstantiator;
  }

  public ActivityDefinitionImpl(ActivityDefinition src) {
    super(src);
    this.uuid = new ActivityDefinitionUUID(src.getUUID());
    this.activityId = src.getActivityId();
    this.blockId = src.getBlockId();
    Set<DeadlineDefinition> deadlines = src.getDeadlines();
    if (deadlines != null) {
      this.deadlines = new HashSet<DeadlineDefinition>();
      for (DeadlineDefinition d : deadlines) {
        this.deadlines.add(new DeadlineDefinitionImpl(d));
      }
    }
    this.description = src.getDescription();
    this.documentation = src.getDocumentation();
    this.finishMode = src.getFinishMode();
    this.icon = src.getIcon();
    this.limit = src.getLimit();
    this.performer = src.getPerformer();
    this.priority = src.getPriority();
    if (src.getSimulationInformation() != null) {
      this.simulationInformation = new SimulationInformationDefinitionImpl(src.getSimulationInformation());
    }
    this.startMode = src.getStartMode();
    if (src.getSubFlow() != null) {
      this.subFlow = new SubFlowDefinitionImpl(src.getSubFlow());
    }
    Set<ToolDefinition> tools = src.getTools();
    if (tools != null) {
      this.tools = new HashSet<ToolDefinition>();
      for (ToolDefinition d : tools) {
        this.tools.add(new ToolDefinitionImpl(d));
      }
    }
    Set<TransitionRestrictionDefinition> transitionRestrictions = src.getTransitionRestrictions();
    if (transitionRestrictions != null) {
      this.transitionRestrictions = new HashSet<TransitionRestrictionDefinition>();
      for (TransitionRestrictionDefinition d : transitionRestrictions) {
        this.transitionRestrictions.add(new TransitionRestrictionDefinitionImpl(d));
      }
    }
    this.noImplementation = src.isNoImplementation();
    this.route = src.isRoute();
    Set<HookDefinition> hooks = src.getHooks();
    if (hooks != null) {
      this.hooks = new HashSet<HookDefinition>();
      for (HookDefinition d : hooks) {
        this.hooks.add(new HookDefinitionImpl(d));
      }
    }
    if (src.getPerformerAssign() != null) {
      this.performerAssign = new PerformerAssignDefinitionImpl(src.getPerformerAssign());
    }
    Set<DataFieldDefinition> dataFields = src.getDataFields();
    if (dataFields != null) {
      this.dataFields = new HashSet<DataFieldDefinition>();
      for (DataFieldDefinition d : dataFields) {
        this.dataFields.add(new DataFieldDefinitionImpl(d));
      }
    }
    if (src.getMultiInstantiationDefinition() != null) {
      this.activityInstantiator = new MultiInstantiationDefinitionImpl(src.getMultiInstantiationDefinition());
    }
  }



  public String getBlockId() {
    return blockId;
  }

  public Set<DeadlineDefinition> getDeadlines() {
    return deadlines;
  }

  public String getDescription() {
    return description;
  }

  public String getDocumentation() {
    return documentation;
  }

  public FinishMode getFinishMode() {
    return finishMode;
  }

  public String getIcon() {
    return icon;
  }

  public String getLimit() {
    return limit;
  }

  public String getPerformer() {
    return performer;
  }

  public String getPriority() {
    return priority;
  }

  public SimulationInformationDefinition getSimulationInformation() {
    return simulationInformation;
  }

  public StartMode getStartMode() {
    return startMode;
  }

  public SubFlowDefinition getSubFlow() {
    return subFlow;
  }

  public Set<ToolDefinition> getTools() {
    return tools;
  }

  public Set<TransitionRestrictionDefinition> getTransitionRestrictions() {
    return transitionRestrictions;
  }

  public boolean isNoImplementation() {
    return noImplementation;
  }

  public boolean isRoute() {
    return route;
  }

  public Set<HookDefinition> getHooks() {
    return hooks;
  }

  public PerformerAssignDefinition getPerformerAssign() {
    return performerAssign;
  }

  public Set<DataFieldDefinition> getDataFields() {
    return dataFields;
  }

  public Set<IterationDef> getIterations() {
    return iterations;
  }

  public String getActivityId() {
    return activityId;
  }


  public ActivityDefinitionUUID getUUID() {
    return uuid;
  }

  
  public MultiInstantiationDefinition getMultiInstantiationDefinition() {
    return activityInstantiator;
  }

}


