/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.facade.def.majorElement.impl;

import java.util.ArrayList;
import java.util.List;

import org.ow2.bonita.facade.def.element.ExternalReferenceDefinition;
import org.ow2.bonita.facade.def.element.FormalParameterDefinition;
import org.ow2.bonita.facade.def.element.impl.ExternalReferenceDefinitionImpl;
import org.ow2.bonita.facade.def.element.impl.FormalParameterDefinitionImpl;
import org.ow2.bonita.facade.def.majorElement.ApplicationDefinition;
import org.ow2.bonita.facade.uuid.ApplicationDefinitionUUID;
import org.ow2.bonita.facade.uuid.PackageDefinitionUUID;
import org.ow2.bonita.facade.uuid.ProcessDefinitionUUID;


public class ApplicationDefinitionImpl extends ProcessDefinitionRecordImpl implements ApplicationDefinition {

  protected ApplicationDefinitionUUID uuid;
  protected String applicationId;
  protected String description;
  protected ExternalReferenceDefinition externalReference;
  protected List<FormalParameterDefinition> formalParameters;

  protected ApplicationDefinitionImpl() { }

  public ApplicationDefinitionImpl(ApplicationDefinitionUUID uuid, String applicationId,
      PackageDefinitionUUID packageUUID, ProcessDefinitionUUID processUUID,
      String description, ExternalReferenceDefinition externalReference,
      List<FormalParameterDefinition> formalParameters, String name) {
    super(packageUUID, name, processUUID);
    this.uuid = uuid;
    this.applicationId = applicationId;
    this.description = description;
    this.externalReference = externalReference;
    this.formalParameters = formalParameters;
  }

  public ApplicationDefinitionImpl(ApplicationDefinition src) {
    super(src);
    this.uuid = new ApplicationDefinitionUUID(src.getUUID());
    this.applicationId = src.getApplicationId();
    this.description = src.getDescription();
    if (src.getExternalReference() != null) {
      this.externalReference = new ExternalReferenceDefinitionImpl(src.getExternalReference());
    }
    List<FormalParameterDefinition> formalParameters = src.getFormalParameters();
    if (formalParameters != null) {
      this.formalParameters = new ArrayList<FormalParameterDefinition>();
      for (FormalParameterDefinition d : formalParameters) {
        this.formalParameters.add(new FormalParameterDefinitionImpl(d));
      }
    }
  }

  public String getDescription() {
    return description;
  }

  public ExternalReferenceDefinition getExternalReference() {
    return externalReference;
  }

  public List<FormalParameterDefinition> getFormalParameters() {
    return formalParameters;
  }

  public String getApplicationId() {
    return applicationId;
  }


  public ApplicationDefinitionUUID getUUID() {
    return uuid;
  }

}


