/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.facade.runtime.impl;

import java.util.Date;

import org.ow2.bonita.facade.runtime.ActivityBody;
import org.ow2.bonita.facade.uuid.ActivityBodyUUID;
import org.ow2.novabpm.util.Misc;


public abstract class ActivityBodyImpl implements ActivityBody {

  protected long dbid;

  protected ActivityBodyUUID uuid;
  protected Date startedDate;
  protected Date endedDate;

  protected ActivityBodyImpl() { }

  protected ActivityBodyImpl(final ActivityBodyUUID uuid) {
    super();
    this.uuid = uuid;
  }

  protected ActivityBodyImpl(final ActivityBody activityBody) {
    super();
    this.uuid = activityBody.getUUID().copy();
    this.startedDate = activityBody.getStartedDate();
    this.endedDate = activityBody.getEndedDate();
  }

  public String toString() {
    return this.getClass().getName()
      + "[uuid: " + getUUID()
      + ", startedDate: " + getStartedDate()
      + ", endedDate: " + getEndedDate()
      + "]";
  }

  public ActivityBodyUUID getUUID() {
    return uuid;
  }

  public Date getStartedDate() {
    return startedDate;
  }

  public Date getEndedDate() {
    return endedDate;
  }

  public void setStartedDate(Date date) {
    Misc.badStateIfNotNull(getStartedDate(), "startedDate can not be set twice!");
    this.startedDate = date;
  }

  public void setEndedDate(Date date) {
    Misc.badStateIfNotNull(getEndedDate(), "endedDate can not be set twice!");
    Misc.badStateIfNull(getStartedDate(), "endedDate can not be set before startedDate!");
    this.endedDate = date;
  }
}


